package AsposeCellsCloud::Object::SaveOptions;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposeCellsCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    'CachedFileFolder' => 'string',
    'ClearData' => 'boolean',
    'CreateDirectory' => 'boolean',
    'EnableHTTPCompression' => 'boolean',
    'RefreshChartCache' => 'boolean',
    'SortNames' => 'boolean',
    'ValidateMergedAreas' => 'boolean'
};

my $attribute_map = {
    'CachedFileFolder' => 'CachedFileFolder',
    'ClearData' => 'ClearData',
    'CreateDirectory' => 'CreateDirectory',
    'EnableHTTPCompression' => 'EnableHTTPCompression',
    'RefreshChartCache' => 'RefreshChartCache',
    'SortNames' => 'SortNames',
    'ValidateMergedAreas' => 'ValidateMergedAreas'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'CachedFileFolder' => $args{'CachedFileFolder'}, 
        #
        'ClearData' => $args{'ClearData'}, 
        #
        'CreateDirectory' => $args{'CreateDirectory'}, 
        #
        'EnableHTTPCompression' => $args{'EnableHTTPCompression'}, 
        #
        'RefreshChartCache' => $args{'RefreshChartCache'}, 
        #
        'SortNames' => $args{'SortNames'}, 
        #
        'ValidateMergedAreas' => $args{'ValidateMergedAreas'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
