package AsposeCellsCloud::Object::Font;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposeCellsCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    'Color' => 'Color',
    'DoubleSize' => 'double',
    'IsBold' => 'boolean',
    'IsItalic' => 'boolean',
    'IsStrikeout' => 'boolean',
    'IsSubscript' => 'boolean',
    'IsSuperscript' => 'boolean',
    'Name' => 'string',
    'Size' => 'int',
    'Underline' => 'string'
};

my $attribute_map = {
    'Color' => 'Color',
    'DoubleSize' => 'DoubleSize',
    'IsBold' => 'IsBold',
    'IsItalic' => 'IsItalic',
    'IsStrikeout' => 'IsStrikeout',
    'IsSubscript' => 'IsSubscript',
    'IsSuperscript' => 'IsSuperscript',
    'Name' => 'Name',
    'Size' => 'Size',
    'Underline' => 'Underline'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'Color' => $args{'Color'}, 
        #
        'DoubleSize' => $args{'DoubleSize'}, 
        #
        'IsBold' => $args{'IsBold'}, 
        #
        'IsItalic' => $args{'IsItalic'}, 
        #
        'IsStrikeout' => $args{'IsStrikeout'}, 
        #
        'IsSubscript' => $args{'IsSubscript'}, 
        #
        'IsSuperscript' => $args{'IsSuperscript'}, 
        #
        'Name' => $args{'Name'}, 
        #
        'Size' => $args{'Size'}, 
        #
        'Underline' => $args{'Underline'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
