package AsposeCellsCloud::Object::Line;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposeCellsCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    'BeginArrowLength' => 'string',
    'BeginArrowWidth' => 'string',
    'BeginType' => 'string',
    'CapType' => 'string',
    'Color' => 'Color',
    'CompoundType' => 'string',
    'DashType' => 'string',
    'EndArrowLength' => 'string',
    'EndArrowWidth' => 'string',
    'EndType' => 'string',
    'GradientFill' => 'GradientFill',
    'IsAuto' => 'boolean',
    'IsAutomaticColor' => 'boolean',
    'IsVisible' => 'boolean',
    'JoinType' => 'string',
    'Style' => 'string',
    'Transparency' => 'double',
    'Weight' => 'string',
    'WeightPt' => 'double'
};

my $attribute_map = {
    'BeginArrowLength' => 'BeginArrowLength',
    'BeginArrowWidth' => 'BeginArrowWidth',
    'BeginType' => 'BeginType',
    'CapType' => 'CapType',
    'Color' => 'Color',
    'CompoundType' => 'CompoundType',
    'DashType' => 'DashType',
    'EndArrowLength' => 'EndArrowLength',
    'EndArrowWidth' => 'EndArrowWidth',
    'EndType' => 'EndType',
    'GradientFill' => 'GradientFill',
    'IsAuto' => 'IsAuto',
    'IsAutomaticColor' => 'IsAutomaticColor',
    'IsVisible' => 'IsVisible',
    'JoinType' => 'JoinType',
    'Style' => 'Style',
    'Transparency' => 'Transparency',
    'Weight' => 'Weight',
    'WeightPt' => 'WeightPt'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'BeginArrowLength' => $args{'BeginArrowLength'}, 
        #
        'BeginArrowWidth' => $args{'BeginArrowWidth'}, 
        #
        'BeginType' => $args{'BeginType'}, 
        #
        'CapType' => $args{'CapType'}, 
        #
        'Color' => $args{'Color'}, 
        #
        'CompoundType' => $args{'CompoundType'}, 
        #
        'DashType' => $args{'DashType'}, 
        #
        'EndArrowLength' => $args{'EndArrowLength'}, 
        #
        'EndArrowWidth' => $args{'EndArrowWidth'}, 
        #
        'EndType' => $args{'EndType'}, 
        #
        'GradientFill' => $args{'GradientFill'}, 
        #
        'IsAuto' => $args{'IsAuto'}, 
        #
        'IsAutomaticColor' => $args{'IsAutomaticColor'}, 
        #
        'IsVisible' => $args{'IsVisible'}, 
        #
        'JoinType' => $args{'JoinType'}, 
        #
        'Style' => $args{'Style'}, 
        #
        'Transparency' => $args{'Transparency'}, 
        #
        'Weight' => $args{'Weight'}, 
        #
        'WeightPt' => $args{'WeightPt'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
