package AsposeCellsCloud::Object::Comment;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposeCellsCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    'CellName' => 'string',
    'Author' => 'string',
    'HtmlNote' => 'string',
    'Note' => 'string',
    'AutoSize' => 'boolean',
    'IsVisible' => 'boolean',
    'Width' => 'int',
    'Height' => 'int',
    'TextHorizontalAlignment' => 'string',
    'TextOrientationType' => 'string',
    'TextVerticalAlignment' => 'string',
    'link' => 'Link'
};

my $attribute_map = {
    'CellName' => 'CellName',
    'Author' => 'Author',
    'HtmlNote' => 'HtmlNote',
    'Note' => 'Note',
    'AutoSize' => 'AutoSize',
    'IsVisible' => 'IsVisible',
    'Width' => 'Width',
    'Height' => 'Height',
    'TextHorizontalAlignment' => 'TextHorizontalAlignment',
    'TextOrientationType' => 'TextOrientationType',
    'TextVerticalAlignment' => 'TextVerticalAlignment',
    'link' => 'link'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'CellName' => $args{'CellName'}, 
        #
        'Author' => $args{'Author'}, 
        #
        'HtmlNote' => $args{'HtmlNote'}, 
        #
        'Note' => $args{'Note'}, 
        #
        'AutoSize' => $args{'AutoSize'}, 
        #
        'IsVisible' => $args{'IsVisible'}, 
        #
        'Width' => $args{'Width'}, 
        #
        'Height' => $args{'Height'}, 
        #
        'TextHorizontalAlignment' => $args{'TextHorizontalAlignment'}, 
        #
        'TextOrientationType' => $args{'TextOrientationType'}, 
        #
        'TextVerticalAlignment' => $args{'TextVerticalAlignment'}, 
        #
        'link' => $args{'link'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
