package AsposeCellsCloud::Object::PatternFill;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposeCellsCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    'Pattern' => 'string',
    'BackgroundCellsColor' => 'CellsColor',
    'ForegroundCellsColor' => 'CellsColor',
    'ForegroundColor' => 'Color',
    'BackgroundColor' => 'Color',
    'BackTransparency' => 'double',
    'ForeTransparency' => 'double'
};

my $attribute_map = {
    'Pattern' => 'Pattern',
    'BackgroundCellsColor' => 'BackgroundCellsColor',
    'ForegroundCellsColor' => 'ForegroundCellsColor',
    'ForegroundColor' => 'ForegroundColor',
    'BackgroundColor' => 'BackgroundColor',
    'BackTransparency' => 'BackTransparency',
    'ForeTransparency' => 'ForeTransparency'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'Pattern' => $args{'Pattern'}, 
        #
        'BackgroundCellsColor' => $args{'BackgroundCellsColor'}, 
        #
        'ForegroundCellsColor' => $args{'ForegroundCellsColor'}, 
        #
        'ForegroundColor' => $args{'ForegroundColor'}, 
        #
        'BackgroundColor' => $args{'BackgroundColor'}, 
        #
        'BackTransparency' => $args{'BackTransparency'}, 
        #
        'ForeTransparency' => $args{'ForeTransparency'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
