package AsposeCellsCloud::Object::Validation;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposeCellsCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    'AlertStyle' => 'string',
    'AreaList' => 'ARRAY[CellArea]',
    'ErrorMessage' => 'string',
    'ErrorTitle' => 'string',
    'Formula1' => 'string',
    'Formula2' => 'string',
    'IgnoreBlank' => 'boolean',
    'InCellDropDown' => 'boolean',
    'InputMessage' => 'string',
    'InputTitle' => 'string',
    'Operator' => 'string',
    'ShowError' => 'boolean',
    'ShowInput' => 'boolean',
    'Type' => 'string',
    'Value1' => 'string',
    'Value2' => 'string',
    'link' => 'Link'
};

my $attribute_map = {
    'AlertStyle' => 'AlertStyle',
    'AreaList' => 'AreaList',
    'ErrorMessage' => 'ErrorMessage',
    'ErrorTitle' => 'ErrorTitle',
    'Formula1' => 'Formula1',
    'Formula2' => 'Formula2',
    'IgnoreBlank' => 'IgnoreBlank',
    'InCellDropDown' => 'InCellDropDown',
    'InputMessage' => 'InputMessage',
    'InputTitle' => 'InputTitle',
    'Operator' => 'Operator',
    'ShowError' => 'ShowError',
    'ShowInput' => 'ShowInput',
    'Type' => 'Type',
    'Value1' => 'Value1',
    'Value2' => 'Value2',
    'link' => 'link'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'AlertStyle' => $args{'AlertStyle'}, 
        #
        'AreaList' => $args{'AreaList'}, 
        #
        'ErrorMessage' => $args{'ErrorMessage'}, 
        #
        'ErrorTitle' => $args{'ErrorTitle'}, 
        #
        'Formula1' => $args{'Formula1'}, 
        #
        'Formula2' => $args{'Formula2'}, 
        #
        'IgnoreBlank' => $args{'IgnoreBlank'}, 
        #
        'InCellDropDown' => $args{'InCellDropDown'}, 
        #
        'InputMessage' => $args{'InputMessage'}, 
        #
        'InputTitle' => $args{'InputTitle'}, 
        #
        'Operator' => $args{'Operator'}, 
        #
        'ShowError' => $args{'ShowError'}, 
        #
        'ShowInput' => $args{'ShowInput'}, 
        #
        'Type' => $args{'Type'}, 
        #
        'Value1' => $args{'Value1'}, 
        #
        'Value2' => $args{'Value2'}, 
        #
        'link' => $args{'link'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
