package AsposeCellsCloud::Object::ContentMessage;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposeCellsCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    'Content' => 'string',
    'Headers' => 'string',
    'IsSuccessStatusCode' => 'string',
    'ReasonPhrase' => 'string',
    'RequestMessage' => 'string',
    'StatusCode' => 'string',
    'Version' => 'string'
};

my $attribute_map = {
    'Content' => 'Content',
    'Headers' => 'Headers',
    'IsSuccessStatusCode' => 'IsSuccessStatusCode',
    'ReasonPhrase' => 'ReasonPhrase',
    'RequestMessage' => 'RequestMessage',
    'StatusCode' => 'StatusCode',
    'Version' => 'Version'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'Content' => $args{'Content'}, 
        #
        'Headers' => $args{'Headers'}, 
        #
        'IsSuccessStatusCode' => $args{'IsSuccessStatusCode'}, 
        #
        'ReasonPhrase' => $args{'ReasonPhrase'}, 
        #
        'RequestMessage' => $args{'RequestMessage'}, 
        #
        'StatusCode' => $args{'StatusCode'}, 
        #
        'Version' => $args{'Version'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
