package AsposeCellsCloud::Object::AutoShape;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposeCellsCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    		'AlternativeText' => 'string',
            'Bottom' => 'int',
            'Top' => 'int',
            'Width' => 'int',
            'HtmlText' => 'string',
            'TextVerticalAlignment' => 'string',
            'AutoShapeType' => 'string',
            'IsPrintable' => 'boolean',
            'UpperLeftColumn' => 'int',
            'IsLockAspectRatio' => 'boolean',
            'IsGroup' => 'boolean',
            'RotationAngle' => 'int',
            'ZOrderPosition' => 'int',
            'TextHorizontalOverflow' => 'string',
            'TextOrientationType' => 'string',
            'Placement' => 'string',
            'Name' => 'string',
            'IsWordArt' => 'boolean',
            'LinkedCell' => 'string',
            'UpperLeftRow' => 'int',
            'IsLocked' => 'boolean',
            'LowerRightRow' => 'int',
            'IsTextWrapped' => 'boolean',
            'Y' => 'int',
            'X' => 'int',
            'IsHidden' => 'boolean',
            'Left' => 'int',
            'Right' => 'int',
            'Text' => 'string',
            'LowerRightColumn' => 'int',
            'Height' => 'int',
            'TextHorizontalAlignment' => 'string',
            'TextVerticalOverflow' => 'string',
    		'link' => 'Link'
};

my $attribute_map = {
    		'AlternativeText' => 'AlternativeText',
            'Bottom' => 'Bottom',
            'Top' => 'Top',
            'Width' => 'Width',
            'HtmlText' => 'HtmlText',
            'TextVerticalAlignment' => 'TextVerticalAlignment',
            'AutoShapeType' => 'AutoShapeType',
            'IsPrintable' => 'IsPrintable',
            'UpperLeftColumn' => 'UpperLeftColumn',
            'IsLockAspectRatio' => 'IsLockAspectRatio',
            'IsGroup' => 'IsGroup',
            'RotationAngle' => 'RotationAngle',
            'ZOrderPosition' => 'ZOrderPosition',
            'TextHorizontalOverflow' => 'TextHorizontalOverflow',
            'TextOrientationType' => 'TextOrientationType',
            'Placement' => 'Placement',
            'Name' => 'Name',
            'IsWordArt' => 'IsWordArt',
            'LinkedCell' => 'LinkedCell',
            'UpperLeftRow' => 'UpperLeftRow',
            'IsLocked' => 'IsLocked',
            'LowerRightRow' => 'LowerRightRow',
            'IsTextWrapped' => 'IsTextWrapped',
            'Y' => 'Y',
            'X' => 'X',
            'IsHidden' => 'IsHidden',
            'Left' => 'Left',
            'Right' => 'Right',
            'Text' => 'Text',
            'LowerRightColumn' => 'LowerRightColumn',
            'Height' => 'Height',
            'TextHorizontalAlignment' => 'TextHorizontalAlignment',
            'TextVerticalOverflow' => 'TextVerticalOverflow',
    		'link' => 'link'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'AutoShapeList' => $args{'AutoShapeList'}, 
        #
        'link' => $args{'link'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
