package AsposeCellsCloud::Object::CreatePivotTableRequest;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposeCellsCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    'Name' => 'string',
    'SourceData' => 'string',
    'DestCellName' => 'string',
    'UseSameSource' => 'boolean',
    'PivotFieldRows' => 'ARRAY[int]',
    'PivotFieldColumns' => 'ARRAY[int]',
    'PivotFieldData' => 'ARRAY[int]'
};

my $attribute_map = {
    'Name' => 'Name',
    'SourceData' => 'SourceData',
    'DestCellName' => 'DestCellName',
    'UseSameSource' => 'UseSameSource',
    'PivotFieldRows' => 'PivotFieldRows',
    'PivotFieldColumns' => 'PivotFieldColumns',
    'PivotFieldData' => 'PivotFieldData'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'Name' => $args{'Name'}, 
        #
        'SourceData' => $args{'SourceData'}, 
        #
        'DestCellName' => $args{'DestCellName'}, 
        #
        'UseSameSource' => $args{'UseSameSource'}, 
        #
        'PivotFieldRows' => $args{'PivotFieldRows'}, 
        #
        'PivotFieldColumns' => $args{'PivotFieldColumns'}, 
        #
        'PivotFieldData' => $args{'PivotFieldData'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
