package AsposeCellsCloud::Object::PivotFilter;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposeCellsCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    'AutoFilter' => 'AutoFilter',
    'EvaluationOrder' => 'int',
    'FieldIndex' => 'int',
    'FilterType' => 'string',
    'MeasureFldIndex' => 'int',
    'MemberPropertyFieldIndex' => 'int',
    'Name' => 'string',
    'Value1' => 'string',
    'Value2' => 'string'
};

my $attribute_map = {
    'AutoFilter' => 'AutoFilter',
    'EvaluationOrder' => 'EvaluationOrder',
    'FieldIndex' => 'FieldIndex',
    'FilterType' => 'FilterType',
    'MeasureFldIndex' => 'MeasureFldIndex',
    'MemberPropertyFieldIndex' => 'MemberPropertyFieldIndex',
    'Name' => 'Name',
    'Value1' => 'Value1',
    'Value2' => 'Value2'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'AutoFilter' => $args{'AutoFilter'}, 
        #
        'EvaluationOrder' => $args{'EvaluationOrder'}, 
        #
        'FieldIndex' => $args{'FieldIndex'}, 
        #
        'FilterType' => $args{'FilterType'}, 
        #
        'MeasureFldIndex' => $args{'MeasureFldIndex'}, 
        #
        'MemberPropertyFieldIndex' => $args{'MemberPropertyFieldIndex'}, 
        #
        'Name' => $args{'Name'}, 
        #
        'Value1' => $args{'Value1'}, 
        #
        'Value2' => $args{'Value2'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
