package AsposeCellsCloud::Object::Name;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposeCellsCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    'Comment' => 'string',
    'WorksheetIndex' => 'int',
    'IsReferred' => 'boolean',
    'IsVisible' => 'boolean',
    'R1C1RefersTo' => 'string',
    'RefersTo' => 'string',
    'Text' => 'string',
    'link' => 'Link'
};

my $attribute_map = {
    'Comment' => 'Comment',
    'WorksheetIndex' => 'WorksheetIndex',
    'IsReferred' => 'IsReferred',
    'IsVisible' => 'IsVisible',
    'R1C1RefersTo' => 'R1C1RefersTo',
    'RefersTo' => 'RefersTo',
    'Text' => 'Text',
    'link' => 'link'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'Comment' => $args{'Comment'}, 
        #
        'WorksheetIndex' => $args{'WorksheetIndex'}, 
        #
        'IsReferred' => $args{'IsReferred'}, 
        #
        'IsVisible' => $args{'IsVisible'}, 
        #
        'R1C1RefersTo' => $args{'R1C1RefersTo'}, 
        #
        'RefersTo' => $args{'RefersTo'}, 
        #
        'Text' => $args{'Text'}, 
        #
        'link' => $args{'link'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
