package AsposeCellsCloud::Object::Cell;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposeCellsCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    'Name' => 'string',
    'Row' => 'int',
    'Column' => 'int',
    'Value' => 'string',
    'Type' => 'string',
    'Formula' => 'string',
    'IsFormula' => 'boolean',
    'IsMerged' => 'boolean',
    'IsArrayHeader' => 'boolean',
    'IsInArray' => 'boolean',
    'IsErrorValue' => 'boolean',
    'IsInTable' => 'boolean',
    'IsStyleSet' => 'boolean',
    'HtmlString' => 'string',
    'Style' => 'LinkElement',
    'Worksheet' => 'string',
    'link' => 'Link'
};

my $attribute_map = {
    'Name' => 'Name',
    'Row' => 'Row',
    'Column' => 'Column',
    'Value' => 'Value',
    'Type' => 'Type',
    'Formula' => 'Formula',
    'IsFormula' => 'IsFormula',
    'IsMerged' => 'IsMerged',
    'IsArrayHeader' => 'IsArrayHeader',
    'IsInArray' => 'IsInArray',
    'IsErrorValue' => 'IsErrorValue',
    'IsInTable' => 'IsInTable',
    'IsStyleSet' => 'IsStyleSet',
    'HtmlString' => 'HtmlString',
    'Style' => 'Style',
    'Worksheet' => 'Worksheet',
    'link' => 'link'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'Name' => $args{'Name'}, 
        #
        'Row' => $args{'Row'}, 
        #
        'Column' => $args{'Column'}, 
        #
        'Value' => $args{'Value'}, 
        #
        'Type' => $args{'Type'}, 
        #
        'Formula' => $args{'Formula'}, 
        #
        'IsFormula' => $args{'IsFormula'}, 
        #
        'IsMerged' => $args{'IsMerged'}, 
        #
        'IsArrayHeader' => $args{'IsArrayHeader'}, 
        #
        'IsInArray' => $args{'IsInArray'}, 
        #
        'IsErrorValue' => $args{'IsErrorValue'}, 
        #
        'IsInTable' => $args{'IsInTable'}, 
        #
        'IsStyleSet' => $args{'IsStyleSet'}, 
        #
        'HtmlString' => $args{'HtmlString'}, 
        #
        'Style' => $args{'Style'}, 
        #
        'Worksheet' => $args{'Worksheet'}, 
        #
        'link' => $args{'link'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
